@@ -18,7 +18,7 @@ from reV.utilities.exceptions import (SAMInputWarning, SAMInputError,
 from rex.multi_file_resource import (MultiFileResource, MultiFileNSRDB,
                                      MultiFileWTK)
 from rex.renewable_resource import (WindResource, SolarResource, NSRDB,
-                                    WaveResource)
+                                    WaveResource, GeothermalResource)
 from rex.multi_res_resource import MultiResolutionResource
 from rex.utilities.utilities import check_res_file
 
@@ -29,6 +29,21 @@ logger = logging.getLogger(__name__)
 class SamResourceRetriever:
     """Factory utility to get the SAM resource handler."""
 
+    # Mapping for reV technology and SAM module to h5 resource handler type
+    # SolarResource is swapped for NSRDB if the res_file contains "nsrdb"
+    RESOURCE_TYPES = {'geothermal': GeothermalResource,
+                      'pvwattsv5': SolarResource,
+                      'pvwattsv7': SolarResource,
+                      'pvwattsv8': SolarResource,
+                      'pvsamv1': SolarResource,
+                      'tcsmoltensalt': SolarResource,
+                      'solarwaterheat': SolarResource,
+                      'troughphysicalheat': SolarResource,
+                      'lineardirectsteam': SolarResource,
+                      'windpower': WindResource,
+                      'mhkwave': WaveResource
+                      }
+
     @staticmethod
     def _get_base_handler(res_file, module):
         """Get the base SAM resource handler, raise error if module not found.
@@ -51,13 +66,14 @@ class SamResourceRetriever:
         """
 
         try:
-            res_handler = RevPySam.RESOURCE_TYPES[module.lower()]
+            res_handler = SamResourceRetriever.RESOURCE_TYPES[module.lower()]
 
         except KeyError as e:
             msg = ('Cannot interpret what kind of resource handler the SAM '
                    'module or reV technology "{}" requires. Expecting one of '
                    'the following SAM modules or reV technologies: {}'
-                   .format(module, list(RevPySam.RESOURCE_TYPES.keys())))
+                   .format(module,
+                           list(SamResourceRetriever.RESOURCE_TYPES.keys())))
             logger.exception(msg)
             raise SAMExecutionError(msg) from e
 
@@ -158,6 +174,9 @@ class SamResourceRetriever:
                     # make precip rate available for curtailment analysis
                     kwargs['precip_rate'] = True
 
+        elif res_handler == GeothermalResource:
+            args += (project_points.d, )
+
         # Check for resource means
         if any(req.endswith('_mean') for req in output_request):
             kwargs['means'] = True
@@ -201,7 +220,7 @@ class SamResourceRetriever:
     @classmethod
     def get(cls, res_file, project_points, module,
             output_request=('cf_mean', ), gid_map=None,
-            lr_res_file=None, nn_map=None):
+            lr_res_file=None, nn_map=None, bias_correct=None):
         """Get the SAM resource iterator object (single year, single file).
 
         Parameters
@@ -234,6 +253,16 @@ class SamResourceRetriever:
             Optional 1D array of nearest neighbor mappings associated with the
             res_file to lr_res_file spatial mapping. For details on this
             argument, see the rex.MultiResolutionResource docstring.
+        bias_correct : None | pd.DataFrame
+            None if not provided or extracted DataFrame with wind or solar
+            resource bias correction table. This has columns: gid (can be index
+            name), adder, scalar. If both adder and scalar are present, the
+            wind or solar resource is corrected by (res*scalar)+adder. If
+            either adder or scalar is not present, scalar defaults to 1 and
+            adder to 0. Only windspeed or GHI+DNI are corrected depending on
+            the technology. GHI and DNI are corrected with the same correction
+            factors.
+
 
         Returns
         -------
@@ -264,6 +293,9 @@ class SamResourceRetriever:
             res = MultiResolutionResource.preload_SAM(res_file, lr_res_file,
                                                       *args, **kwargs)
 
+        if bias_correct is not None:
+            res.bias_correct(bias_correct)
+
         return res
 
 
@@ -512,20 +544,6 @@ class RevPySam(Sam):
     DIR = os.path.dirname(os.path.realpath(__file__))
     MODULE = None
 
-    # Mapping for reV technology and SAM module to h5 resource handler type
-    # SolarResource is swapped for NSRDB if the res_file contains "nsrdb"
-    RESOURCE_TYPES = {'pvwattsv5': SolarResource,
-                      'pvwattsv7': SolarResource,
-                      'pvwattsv8': SolarResource,
-                      'pvsamv1': SolarResource,
-                      'tcsmoltensalt': SolarResource,
-                      'solarwaterheat': SolarResource,
-                      'troughphysicalheat': SolarResource,
-                      'lineardirectsteam': SolarResource,
-                      'windpower': WindResource,
-                      'mhkwave': WaveResource
-                      }
-
     def __init__(self, meta, sam_sys_inputs, output_request,
                  site_sys_inputs=None):
         """Initialize a SAM object.
