@@ -10,7 +10,9 @@ import os
 import logging
 import numpy as np
 import pandas as pd
+from tempfile import TemporaryDirectory
 from warnings import warn
+import PySAM.Geothermal as PySamGeothermal
 import PySAM.Pvwattsv5 as PySamPv5
 import PySAM.Pvwattsv7 as PySamPv7
 import PySAM.Pvwattsv8 as PySamPv8
@@ -22,7 +24,8 @@ import PySAM.TroughPhysicalProcessHeat as PySamTpph
 import PySAM.LinearFresnelDsgIph as PySamLds
 import PySAM.MhkWave as PySamMhkWave
 
-from reV.SAM.defaults import (DefaultPvWattsv5,
+from reV.SAM.defaults import (DefaultGeothermal,
+                              DefaultPvWattsv5,
                               DefaultPvWattsv8,
                               DefaultPvSamv1,
                               DefaultWindPower,
@@ -388,7 +391,8 @@ class AbstractSamGeneration(RevPySam, ScheduledLossesMixin, ABC):
     @classmethod
     def reV_run(cls, points_control, res_file, site_df,
                 lr_res_file=None, output_request=('cf_mean',),
-                drop_leap=False, gid_map=None, nn_map=None):
+                drop_leap=False, gid_map=None, nn_map=None,
+                bias_correct=None):
         """Execute SAM generation based on a reV points control instance.
 
         Parameters
@@ -422,6 +426,15 @@ class AbstractSamGeneration(RevPySam, ScheduledLossesMixin, ABC):
             Optional 1D array of nearest neighbor mappings associated with the
             res_file to lr_res_file spatial mapping. For details on this
             argument, see the rex.MultiResolutionResource docstring.
+        bias_correct : None | pd.DataFrame
+            None if not provided or extracted DataFrame with wind or solar
+            resource bias correction table. This has columns: gid (can be index
+            name), adder, scalar. If both adder and scalar are present, the
+            wind or solar resource is corrected by (res*scalar)+adder. If
+            either adder or scalar is not present, scalar defaults to 1 and
+            adder to 0. Only windspeed or GHI+DNI are corrected depending on
+            the technology. GHI and DNI are corrected with the same correction
+            factors.
 
         Returns
         -------
@@ -440,7 +453,8 @@ class AbstractSamGeneration(RevPySam, ScheduledLossesMixin, ABC):
                                          output_request=output_request,
                                          gid_map=gid_map,
                                          lr_res_file=lr_res_file,
-                                         nn_map=nn_map)
+                                         nn_map=nn_map,
+                                         bias_correct=bias_correct)
 
         # run resource through curtailment filter if applicable
         curtailment = points_control.project_points.curtailment
@@ -486,6 +500,140 @@ class AbstractSamGeneration(RevPySam, ScheduledLossesMixin, ABC):
         return out
 
 
+class AbstractSamGenerationFromWeatherFile(AbstractSamGeneration, ABC):
+    """Base class for running sam generation with a weather file on disk. """
+    WF_META_DROP_COLS = {'elevation', 'timezone', 'country', 'state', 'county',
+                         'urban', 'population', 'landcover', 'latitude',
+                         'longitude'}
+
+    @property
+    @abstractmethod
+    def PYSAM_WEATHER_TAG(self):
+        """Name of the weather file input used by SAM generation module."""
+        raise NotImplementedError
+
+    def set_resource_data(self, resource, meta):
+        """Generate the weather file and set the path as an input.
+
+        Some PySAM models require a data file, not raw data. This method
+        generates the weather data, writes it to a file on disk, and
+        then sets the file as an input to the generation module. The
+        function
+        :meth:`~AbstractSamGenerationFromWeatherFile.run_gen_and_econ`
+        deletes the file on disk after a run is complete.
+
+        Parameters
+        ----------
+        resource : pd.DataFrame
+            Time series resource data for a single location with a
+            pandas DatetimeIndex. There must be columns for all the
+            required variables to run the respective SAM simulation.
+            Remapping will be done to convert typical NSRDB/WTK names
+            into SAM names (e.g. DNI -> dn and wind_speed -> windspeed).
+        meta : pd.DataFrame | pd.Series
+            Meta data corresponding to the resource input for the single
+            location. Should include values for latitude, longitude,
+            elevation, and timezone.
+        """
+        self.time_interval = self.get_time_interval(resource.index.values)
+        pysam_w_fname = self._create_pysam_wfile(resource, meta)
+        self[self.PYSAM_WEATHER_TAG] = pysam_w_fname
+
+    def _create_pysam_wfile(self, resource, meta):
+        """Create PySAM weather input file.
+
+        Parameters
+        ----------
+        resource : pd.DataFrame
+            Time series resource data for a single location with a
+            pandas DatetimeIndex. There must be columns for all the
+            required variables to run the respective SAM simulation.
+            Remapping will be done to convert typical NSRDB/WTK names
+            into SAM names (e.g. DNI -> dn and wind_speed -> windspeed).
+        meta : pd.DataFrame | pd.Series
+            Meta data corresponding to the resource input for the single
+            location. Should include values for latitude, longitude,
+            elevation, and timezone.
+
+        Returns
+        -------
+        fname : str
+            Name of weather csv file.
+
+        Notes
+        -----
+        PySAM will not accept data on Feb 29th. For leap years,
+        December 31st is dropped and time steps are shifted to relabel
+        Feb 29th as March 1st, March 1st as March 2nd, etc.
+        """
+        # pylint: disable=attribute-defined-outside-init,consider-using-with
+        self._temp_dir = TemporaryDirectory()
+        fname = os.path.join(self._temp_dir.name, 'weather.csv')
+        logger.debug('Creating PySAM weather data file: {}'.format(fname))
+
+        # ------- Process metadata
+        m = pd.DataFrame(meta).T
+        timezone = m['timezone']
+        m['Source'] = 'NSRDB'
+        m['Location ID'] = meta.name
+        m['City'] = '-'
+        m['State'] = m['state'].apply(lambda x: '-' if x == 'None' else x)
+        m['Country'] = m['country'].apply(lambda x: '-' if x == 'None' else x)
+        m['Latitude'] = m['latitude']
+        m['Longitude'] = m['longitude']
+        m['Time Zone'] = timezone
+        m['Elevation'] = m['elevation']
+        m['Local Time Zone'] = timezone
+        m['Dew Point Units'] = 'c'
+        m['DHI Units'] = 'w/m2'
+        m['DNI Units'] = 'w/m2'
+        m['Temperature Units'] = 'c'
+        m['Pressure Units'] = 'mbar'
+        m['Wind Speed'] = 'm/s'
+        keep_cols = [c for c in m.columns if c not in self.WF_META_DROP_COLS]
+        m[keep_cols].to_csv(fname, index=False, mode='w')
+
+        # --------- Process data
+        var_map = {'dni': 'DNI',
+                   'dhi': 'DHI',
+                   'wind_speed': 'Wind Speed',
+                   'air_temperature': 'Temperature',
+                   'dew_point': 'Dew Point',
+                   'surface_pressure': 'Pressure',
+                   }
+        resource = resource.rename(mapper=var_map, axis='columns')
+
+        time_index = resource.index
+        # Adjust from UTC to local time
+        local = np.roll(resource.values, int(timezone * self.time_interval),
+                        axis=0)
+        resource = pd.DataFrame(local, columns=resource.columns,
+                                index=time_index)
+        mask = (time_index.month == 2) & (time_index.day == 29)
+        time_index = time_index[~mask]
+
+        df = pd.DataFrame(index=time_index)
+        df['Year'] = time_index.year
+        df['Month'] = time_index.month
+        df['Day'] = time_index.day
+        df['Hour'] = time_index.hour
+        df['Minute'] = time_index.minute
+        df = df.join(resource.loc[~mask])
+
+        df.to_csv(fname, index=False, mode='a')
+
+        return fname
+
+    def run_gen_and_econ(self):
+        """Run SAM generation and possibility follow-on econ analysis."""
+        try:
+            super().run_gen_and_econ()
+        finally:
+            temp_dir = getattr(self, "_temp_dir", None)
+            if temp_dir is not None:
+                temp_dir.cleanup()
+
+
 class AbstractSamSolar(AbstractSamGeneration, ABC):
     """Base Class for Solar generation from SAM"""
 
@@ -937,132 +1085,7 @@ class TcsMoltenSalt(AbstractSamSolar):
         return DefaultTcsMoltenSalt.default()
 
 
-class AbstractSamSolarThermal(AbstractSamSolar, ABC):
-    """Base class for solar thermal """
-    PYSAM_WEATHER_TAG = None
-
-    def set_resource_data(self, resource, meta):
-        """
-        Set NSRDB resource file. Overloads Solar.set_resource_data(). Solar
-        thermal PySAM models require a data file, not raw data.
-
-        Parameters
-        ----------
-        resource : pd.DataFrame
-            Timeseries solar or wind resource data for a single location with a
-            pandas DatetimeIndex.  There must be columns for all the required
-            variables to run the respective SAM simulation. Remapping will be
-            done to convert typical NSRDB/WTK names into SAM names (e.g. DNI ->
-            dn and wind_speed -> windspeed)
-        meta : pd.DataFrame | pd.Series
-            Meta data corresponding to the resource input for the single
-            location. Should include values for latitude, longitude, elevation,
-            and timezone.
-        """
-        self.time_interval = self.get_time_interval(resource.index.values)
-        pysam_w_fname = self._create_pysam_wfile(resource, meta)
-        # pylint: disable=E1101
-        self[self.PYSAM_WEATHER_TAG] = pysam_w_fname
-
-    def _create_pysam_wfile(self, resource, meta):
-        """
-        Create PySAM weather input file. PySAM will not accept data on Feb
-        29th. For leap years, December 31st is dropped and time steps are
-        shifted to relabel Feb 29th as March 1st, March 1st as March 2nd, etc.
-
-        Parameters
-        ----------
-        resource : pd.DataFrame
-            Timeseries solar or wind resource data for a single location with a
-            pandas DatetimeIndex.  There must be columns for all the required
-            variables to run the respective SAM simulation. Remapping will be
-            done to convert typical NSRDB/WTK names into SAM names (e.g. DNI ->
-            dn and wind_speed -> windspeed)
-        meta : pd.DataFrame | pd.Series
-            Meta data corresponding to the resource input for the single
-            location. Should include values for latitude, longitude, elevation,
-            and timezone.
-
-        Returns
-        -------
-        fname : string
-            Name of weather csv file
-        """
-        fname = '{}_weather.csv'.format(self._site)
-        logger.debug('Creating PySAM weather data file: {}'.format(fname))
-
-        # ------- Process metadata
-        m = pd.DataFrame(meta).T
-        timezone = m['timezone']
-        m['Source'] = 'NSRDB'
-        m['Location ID'] = meta.name
-        m['City'] = '-'
-        m['State'] = m['state'].apply(lambda x: '-' if x == 'None' else x)
-        m['Country'] = m['country'].apply(lambda x: '-' if x == 'None' else x)
-        m['Latitude'] = m['latitude']
-        m['Longitude'] = m['longitude']
-        m['Time Zone'] = timezone
-        m['Elevation'] = m['elevation']
-        m['Local Time Zone'] = timezone
-        m['Dew Point Units'] = 'c'
-        m['DHI Units'] = 'w/m2'
-        m['DNI Units'] = 'w/m2'
-        m['Temperature Units'] = 'c'
-        m['Pressure Units'] = 'mbar'
-        m['Wind Speed'] = 'm/s'
-        m = m.drop(['elevation', 'timezone', 'country', 'state', 'county',
-                    'urban', 'population', 'landcover', 'latitude',
-                    'longitude'], axis=1)
-        m.to_csv(fname, index=False, mode='w')
-
-        # --------- Process data
-        var_map = {'dni': 'DNI',
-                   'dhi': 'DHI',
-                   'wind_speed': 'Wind Speed',
-                   'air_temperature': 'Temperature',
-                   'dew_point': 'Dew Point',
-                   'surface_pressure': 'Pressure',
-                   }
-        resource = resource.rename(mapper=var_map, axis='columns')
-
-        time_index = resource.index
-        # Adjust from UTC to local time
-        local = np.roll(resource.values, int(timezone * self.time_interval),
-                        axis=0)
-        resource = pd.DataFrame(local, columns=resource.columns,
-                                index=time_index)
-        mask = (time_index.month == 2) & (time_index.day == 29)
-        time_index = time_index[~mask]
-
-        df = pd.DataFrame(index=time_index)
-        df['Year'] = time_index.year
-        df['Month'] = time_index.month
-        df['Day'] = time_index.day
-        df['Hour'] = time_index.hour
-        df['Minute'] = time_index.minute
-        df = df.join(resource.loc[~mask])
-
-        df.to_csv(fname, index=False, mode='a')
-
-        return fname
-
-    def run_gen_and_econ(self, delete_wfile=True):
-        """
-        Run SAM generation with possibility for follow on econ analysis.
-
-        Parameters
-        ----------
-        delete_wfile : bool
-            Delete PySAM weather file after processing is complete
-        """
-        super().run_gen_and_econ()
-
-        pysam_w_fname = self[self.PYSAM_WEATHER_TAG]
-        if delete_wfile and os.path.exists(pysam_w_fname):
-            os.remove(pysam_w_fname)
-
-
-class SolarWaterHeat(AbstractSamSolarThermal):
+class SolarWaterHeat(AbstractSamGenerationFromWeatherFile):
     """
     Solar Water Heater generation
     """
@@ -1081,7 +1104,7 @@ class SolarWaterHeat(AbstractSamSolarThermal):
         return DefaultSwh.default()
 
 
-class LinearDirectSteam(AbstractSamSolarThermal):
+class LinearDirectSteam(AbstractSamGenerationFromWeatherFile):
     """
     Process heat linear Fresnel direct steam generation
     """
@@ -1115,7 +1138,7 @@ class LinearDirectSteam(AbstractSamSolarThermal):
         return DefaultLinearFresnelDsgIph.default()
 
 
-class TroughPhysicalHeat(AbstractSamSolarThermal):
+class TroughPhysicalHeat(AbstractSamGenerationFromWeatherFile):
     """
     Trough Physical Process Heat generation
     """
@@ -1149,6 +1172,263 @@ class TroughPhysicalHeat(AbstractSamSolarThermal):
         return DefaultTroughPhysicalProcessHeat.default()
 
 
+class Geothermal(AbstractSamGenerationFromWeatherFile):
+    """reV-SAM geothermal generation.
+
+    Unlike wind or solar, reV geothermal dynamically sets the size of a
+    geothermal plant. In particular, the nameplate capacity is set to
+    match the resource potential (obtained form the input data) for each
+    site. As a result, reV allows users to input ``capital_cost_per_kw``
+    and ``fixed_operating_cost_per_kw`` instead of the flat
+    ``capital_cost`` and ``fixed_operating_cost`` values, respectively,
+    in the SAM technology config. If these inputs are detected, reV
+    calculates the total ``capital_cost`` and ``fixed_operating_cost``
+    based on the plant size and automatically adds them to the SAM
+    config on a per-site basis.
+
+    As of 12/20/2022, the resource potential input is only used to
+    calculate the number of well replacements during the lifetime of a
+    geothermal plant. It was decided that reV would not model well
+    replacements. Therefore, reV sets the resource potential to match
+    (or be just above) the gross potential so that SAM does not throw
+    any errors.
+
+    Also as of 12/20/2022, the SAM GETEM module requires a weather file,
+    but does not actually require any weather data to run. Therefore,
+    reV currently generates an empty weather file to pass to SAM. This
+    behavior can be easily updated in the future should the SAM GETEM
+    module start using weather data.
+    """
+
+    MODULE = 'geothermal'
+    PYSAM = PySamGeothermal
+    PYSAM_WEATHER_TAG = "file_name"
+    _RESOURCE_POTENTIAL_MULT = 1.001
+
+    @staticmethod
+    def default():
+        """Get the executed default PySAM Geothermal object.
+
+        Returns
+        -------
+        PySAM.Geothermal
+        """
+        return DefaultGeothermal.default()
+
+    def cf_profile(self):
+        """Get hourly capacity factor (frac) profile in local timezone.
+        See self.outputs attribute for collected output data in UTC.
+
+        Returns
+        -------
+        cf_profile : np.ndarray
+            1D numpy array of capacity factor profile.
+            Datatype is float32 and array length is 8760*time_interval.
+        """
+        return self.gen_profile() / self.sam_sys_inputs['nameplate']
+
+    def assign_inputs(self):
+        """Assign the self.sam_sys_inputs attribute to the PySAM object."""
+        if self.sam_sys_inputs.get("ui_calculations_only"):
+            msg = ('reV requires model run - cannot set '
+                   '"ui_calculations_only" to `True` (1). Automatically '
+                   'setting to `False` (0)!')
+            logger.warning(msg)
+            warn(msg)
+            self.sam_sys_inputs["ui_calculations_only"] = 0
+        super().assign_inputs()
+
+    def set_resource_data(self, resource, meta):
+        """Generate the weather file and set the path as an input.
+
+        The Geothermal PySAM model requires a data file, not raw data.
+        This method generates the weather data, writes it to a file on
+        disk, and then sets the file as an input to the Geothermal
+        generation module. The function
+        :meth:`~AbstractSamGenerationFromWeatherFile.run_gen_and_econ`
+        deletes the file on disk after a run is complete.
+
+        Parameters
+        ----------
+        resource : pd.DataFrame
+            Time series resource data for a single location with a
+            pandas DatetimeIndex. There must be columns for all the
+            required variables to run the respective SAM simulation.
+        meta : pd.DataFrame | pd.Series
+            Meta data corresponding to the resource input for the single
+            location. Should include values for latitude, longitude,
+            elevation, and timezone.
+        """
+        super().set_resource_data(resource, meta)
+        self._set_resource_temperature(resource)
+        self._set_nameplate_to_match_resource_potential(resource)
+        self._set_resource_potential_to_match_gross_output()
+        self._set_costs()
+
+    def _set_resource_temperature(self, resource):
+        """Set resource temp from data if user did not specify it. """
+
+        if "resource_temp" in self.sam_sys_inputs:
+            logger.debug("Found 'resource_temp' value in SAM config: {:.2f}"
+                         .format(self.sam_sys_inputs["resource_temp"]))
+            return
+
+        val = set(resource["temperature"].unique())
+        logger.debug("Found {} value(s) for 'temperature' in resource data"
+                     .format(len(val)))
+        if len(val) > 1:
+            msg = ("Found multiple values for 'temperature' for site {}: {}"
+                   .format(self.site, val))
+            logger.error(msg)
+            raise InputError(msg)
+
+        val = val.pop()
+        logger.debug("Input 'resource_temp' not found in SAM config - setting "
+                     "to {:.2f} based on input resource data."
+                     .format(val))
+        self.sam_sys_inputs["resource_temp"] = val
+
+    def _set_nameplate_to_match_resource_potential(self, resource):
+        """Set the nameplate capacity to match the resource potential. """
+
+        val = set(resource["potential_MW"].unique())
+        if len(val) > 1:
+            msg = ('Found multiple values for "potential_MW" for site {}: {}'
+                   .format(self.site, val))
+            logger.error(msg)
+            raise InputError(msg)
+
+        val = val.pop() * 1000
+        if "nameplate" in self.sam_sys_inputs:
+            msg = ('Setting "nameplate" is not allowed! Updating '
+                   'user input of {} to match the resource potential: {}'
+                   .format(self.sam_sys_inputs["nameplate"], val))
+            logger.warning(msg)
+            warn(msg)
+
+        logger.debug("Setting the nameplate to {}".format(val))
+        self.sam_sys_inputs["nameplate"] = val
+
+    def _set_resource_potential_to_match_gross_output(self):
+        """Set the resource potential input to match the gross generation.
+
+        If SAM throws an error during the UI calculation of the gross
+        output, the resource_potential is simply set to -1 since
+        SAM will error out for this point regardless of the
+        resource_potential input.
+        """
+
+        super().assign_inputs()
+        self["ui_calculations_only"] = 1
+        try:
+            self.execute()
+        except SAMExecutionError:
+            self["ui_calculations_only"] = 0
+            self.sam_sys_inputs["resource_potential"] = -1
+            return
+
+        gross_gen = (getattr(self.pysam.Outputs, "gross_output")
+                     * self._RESOURCE_POTENTIAL_MULT)
+        if "resource_potential" in self.sam_sys_inputs:
+            msg = ('Setting "resource_potential" is not allowed! Updating '
+                   'user input of {} to match the gross generation: {}'
+                   .format(self.sam_sys_inputs["resource_potential"],
+                           gross_gen))
+            logger.warning(msg)
+            warn(msg)
+
+        logger.debug("Setting the resource potential to {} MW"
+                     .format(gross_gen))
+        self.sam_sys_inputs["resource_potential"] = gross_gen
+        self["ui_calculations_only"] = 0
+
+    def _set_costs(self):
+        """Set the costs based on gross plant generation."""
+        plant_size_kw = (self.sam_sys_inputs["resource_potential"]
+                         / self._RESOURCE_POTENTIAL_MULT) * 1000
+
+        cc_per_kw = self.sam_sys_inputs.pop("capital_cost_per_kw", None)
+        if cc_per_kw is not None:
+            capital_cost = cc_per_kw * plant_size_kw
+            logger.debug("Setting the capital_cost to ${:,.2f}"
+                         .format(capital_cost))
+            self.sam_sys_inputs["capital_cost"] = capital_cost
+
+        foc_per_kw = self.sam_sys_inputs.pop("fixed_operating_cost_per_kw",
+                                             None)
+        if foc_per_kw is not None:
+            fixed_operating_cost = foc_per_kw * plant_size_kw
+            logger.debug("Setting the fixed_operating_cost to ${:,.2f}"
+                         .format(capital_cost))
+            self.sam_sys_inputs["fixed_operating_cost"] = fixed_operating_cost
+
+    def _create_pysam_wfile(self, resource, meta):
+        """Create PySAM weather input file.
+
+        Geothermal module requires a weather file, but does not actually
+        require any weather data to run. Therefore, an empty file is
+        generated and passed through.
+
+        Parameters
+        ----------
+        resource : pd.DataFrame
+            Time series resource data for a single location with a
+            pandas DatetimeIndex. There must be columns for all the
+            required variables to run the respective SAM simulation.
+        meta : pd.DataFrame | pd.Series
+            Meta data corresponding to the resource input for the single
+            location. Should include values for latitude, longitude,
+            and timezone.
+
+        Returns
+        -------
+        fname : str
+            Name of weather csv file.
+
+        Notes
+        -----
+        PySAM will not accept data on Feb 29th. For leap years,
+        December 31st is dropped and time steps are shifted to relabel
+        Feb 29th as March 1st, March 1st as March 2nd, etc.
+        """
+        # pylint: disable=attribute-defined-outside-init, consider-using-with
+        self._temp_dir = TemporaryDirectory()
+        fname = os.path.join(self._temp_dir.name, 'weather.csv')
+        logger.debug('Creating PySAM weather data file: {}'.format(fname))
+
+        # ------- Process metadata
+        m = pd.DataFrame(meta).T
+        m = m.rename({"latitude": "Latitude", "longitude": "Longitude",
+                      "timezone": "Time Zone"}, axis=1)
+
+        m[["Latitude", "Longitude", "Time Zone"]].to_csv(fname, index=False,
+                                                         mode='w')
+
+        # --------- Process data, blank for geothermal
+        time_index = resource.index
+        mask = (time_index.month == 2) & (time_index.day == 29)
+        time_index = time_index[~mask]
+
+        df = pd.DataFrame(index=time_index)
+        df['Year'] = time_index.year
+        df['Month'] = time_index.month
+        df['Day'] = time_index.day
+        df['Hour'] = time_index.hour
+        df['Minute'] = time_index.minute
+        df.to_csv(fname, index=False, mode='a')
+
+        return fname
+
+    def run_gen_and_econ(self):
+        """Run SAM generation and possibility follow-on econ analysis."""
+        try:
+            super().run_gen_and_econ()
+        except SAMExecutionError as e:
+            logger.error("Skipping site {}; received sam error: {}"
+                         .format(self._site, str(e)))
+            self.outputs = {}
+
+
 class AbstractSamWind(AbstractSamGeneration, PowerCurveLossesMixin, ABC):
     """Base Class for Wind generation from SAM"""
 
