@@ -43,6 +43,7 @@ class PowerCurve:
     that it adheres to the expected pattern of dropping from max rated
     power to zero power in a single wind speed step.
     """
+
     def __init__(self, wind_speed, generation):
         """
         Parameters
@@ -61,6 +62,7 @@ class PowerCurve:
         self.wind_speed = np.array(wind_speed)
         self.generation = np.array(generation)
         self._cutoff_wind_speed = None
+        self._cutin_wind_speed = None
 
         _validate_arrays_not_empty(self,
                                    array_names=['wind_speed', 'generation'])
@@ -93,6 +95,22 @@ class PowerCurve:
                 logger.error(msg)
                 raise reVLossesValueError(msg)
 
+    @property
+    def cutin_wind_speed(self):
+        """The detected cut-in wind speed at which power generation begins
+
+        Returns
+        --------
+        float
+        """
+        if self._cutin_wind_speed is None:
+            ind = np.where(self.generation > 0)[0][0]
+            if ind > 0:
+                self._cutin_wind_speed = self.wind_speed[ind - 1]
+            else:
+                self._cutin_wind_speed = 0
+        return self._cutin_wind_speed
+
     @property
     def cutoff_wind_speed(self):
         """The detected cutoff wind speed at which the power generation is zero
@@ -201,7 +219,7 @@ class PowerCurveLosses:
         corresponding wind speed.
     """
 
-    def __init__(self, power_curve, wind_resource, weights=None):
+    def __init__(self, power_curve, wind_resource, weights=None, site=None):
         """
         Parameters
         ----------
@@ -222,7 +240,10 @@ class PowerCurveLosses:
             An iterable of the same length as ``wind_resource``
             containing weights to apply to each generation value
             calculated for the corresponding wind speed.
+        site : int
+            Site number (gid) for debugging and logging
         """
+
         self.power_curve = power_curve
         self.wind_resource = np.array(wind_resource)
         if weights is None:
@@ -230,6 +251,7 @@ class PowerCurveLosses:
         else:
             self.weights = np.array(weights)
         self._power_gen = None
+        self.site = site
 
         _validate_arrays_not_empty(self,
                                    array_names=['wind_resource', 'weights'])
@@ -239,8 +261,9 @@ class PowerCurveLosses:
     def _validate_wind_resource(self):
         """Validate that the input wind resource is non-negative. """
         if not (self.wind_resource >= 0).all():
-            msg = ("Invalid wind resource input: Contains negative values!"
-                   " - {}".format(self.wind_resource))
+            msg = ("Invalid wind resource input for site {}: Contains "
+                   "negative values! - {}"
+                   .format(self.site, self.wind_resource))
             msg = msg.format(self.wind_resource)
             logger.error(msg)
             raise reVLossesValueError(msg)
@@ -249,9 +272,9 @@ class PowerCurveLosses:
         """Validate that the input weights size matches the wind resource. """
         if self.wind_resource.size != self.weights.size:
             msg = ("Invalid weights input: Does not match size of wind "
-                   "resource! - {} vs {}"
-                   .format(self.weights.size, self.wind_resource.size))
-            msg = msg.format(self.wind_resource)
+                   "resource for site {}! - {} vs {}"
+                   .format(self.site, self.weights.size,
+                           self.wind_resource.size))
             logger.error(msg)
             raise reVLossesValueError(msg)
 
@@ -337,17 +360,43 @@ class PowerCurveLosses:
         transformation = transformation(self.power_curve)
         fit_var = minimize_scalar(self._obj,
                                   args=(target, transformation),
-                                  bounds=transformation.bounds,
+                                  bounds=transformation.optm_bounds,
                                   method='bounded').x
-        loss_percentage = self._obj(fit_var, target, transformation)
-        if loss_percentage > 1:
-            msg = ("Unable to find a transformation such that the losses meet "
-                   "the target within 1%! Obtained fit with loss percentage "
-                   "{}% when target was {}%. Consider using a different "
-                   "transformation or reducing the target losses!"
-                   .format(loss_percentage, target))
+
+        if fit_var > np.max(transformation.bounds):
+            msg = ('Transformation "{}" for site {} resulted in fit parameter '
+                   '{} greater than the max bound of {}. Limiting to the max '
+                   'bound, but the applied losses may not be correct.'
+                   .format(transformation, self.site, fit_var,
+                           np.max(transformation.bounds)))
             logger.warning(msg)
             warnings.warn(msg, reVLossesWarning)
+            fit_var = np.max(transformation.bounds)
+
+        if fit_var < np.min(transformation.bounds):
+            msg = ('Transformation "{}" for site {} resulted in fit parameter '
+                   '{} less than the min bound of {}. Limiting to the min '
+                   'bound, but the applied losses may not be correct.'
+                   .format(transformation, self.site, fit_var,
+                           np.min(transformation.bounds)))
+            logger.warning(msg)
+            warnings.warn(msg, reVLossesWarning)
+            fit_var = np.min(transformation.bounds)
+
+        error = self._obj(fit_var, target, transformation)
+
+        if error > 1:
+            new_power_curve = transformation.apply(fit_var)
+            losses = self.annual_losses_with_transformed_power_curve(
+                new_power_curve)
+            msg = ("Unable to find a transformation for site {} such that the "
+                   "losses meet the target within 1%! Obtained fit with loss "
+                   "percentage {}% when target was {}%. Consider using a "
+                   "different transformation or reducing the target losses!"
+                   .format(self.site, losses, target))
+            logger.warning(msg)
+            warnings.warn(msg, reVLossesWarning)
+
         return transformation.apply(fit_var)
 
     @property
@@ -487,8 +536,28 @@ class PowerCurveLossesMixin:
             return
 
         wind_resource, weights = self.wind_resource_from_input()
-        pc_losses = PowerCurveLosses(self.input_power_curve,
-                                     wind_resource, weights)
+        power_curve = self.input_power_curve
+
+        if (wind_resource <= power_curve.cutin_wind_speed).all():
+            msg = ("All wind speeds for site {} are below the wind speed "
+                   "cutin ({} m/s). No power curve adjustments made!"
+                   .format(getattr(self, "_site", "[unknown]"),
+                           power_curve.cutin_wind_speed))
+            logger.warning(msg)
+            warnings.warn(msg, reVLossesWarning)
+            return
+
+        if (wind_resource >= power_curve.cutoff_wind_speed).all():
+            msg = ("All wind speeds for site {} are above the wind speed "
+                   "cutoff ({} m/s). No power curve adjustments made!"
+                   .format(getattr(self, "_site", "[unknown]"),
+                           power_curve.cutoff_wind_speed))
+            logger.warning(msg)
+            warnings.warn(msg, reVLossesWarning)
+            return
+
+        pc_losses = PowerCurveLosses(power_curve, wind_resource, weights,
+                                     site=getattr(self, 'site', None))
 
         logger.debug("Transforming power curve using the {} transformation to "
                      "meet {}% loss target..."
@@ -627,6 +696,7 @@ class AbstractPowerCurveTransformation(ABC):
         A :obj:`PowerCurve` object representing the "original" power
         curve.
     """
+
     def __init__(self, power_curve):
         """
         Parameters
@@ -714,7 +784,14 @@ class AbstractPowerCurveTransformation(ABC):
     @property
     @abstractmethod
     def bounds(self):
-        """tuple: Bounds on the ``transformation_var``."""
+        """tuple: true Bounds on the ``transformation_var``."""
+
+    @property
+    def optm_bounds(self):
+        """Bounds for scipy optimization, sometimes more generous than the
+        actual fit parameter bounds which are enforced after the
+        optimization."""
+        return self.bounds
 
 
 class HorizontalTranslation(AbstractPowerCurveTransformation):
@@ -781,7 +858,8 @@ class HorizontalTranslation(AbstractPowerCurveTransformation):
 
     @property
     def bounds(self):
-        """tuple: Bounds on the power curve shift for the fitting procedure."""
+        """tuple: true Bounds on the power curve shift (different from the
+        optimization boundaries)"""
         min_ind = np.where(self.power_curve)[0][0]
         max_ind = np.where(self.power_curve[::-1])[0][0]
         max_shift = (self.power_curve.wind_speed[-max_ind - 1]
@@ -841,7 +919,8 @@ class LinearStretching(AbstractPowerCurveTransformation):
 
     @property
     def bounds(self):
-        """tuple: Bounds on the wind speed multiplier."""
+        """tuple: true Bounds on the wind speed multiplier (different from the
+        optimization boundaries)"""
         min_ind_pc = np.where(self.power_curve)[0][0]
         min_ind_ws = np.where(self.power_curve.wind_speed > 1)[0][0]
         min_ws = self.power_curve.wind_speed[max(min_ind_pc, min_ind_ws)]
@@ -912,6 +991,13 @@ class ExponentialStretching(AbstractPowerCurveTransformation):
         max_exponent = np.ceil(np.log(max_ws) / np.log(min_ws))
         return (1, max_exponent)
 
+    @property
+    def optm_bounds(self):
+        """Bounds for scipy optimization, sometimes more generous than the
+        actual fit parameter bounds which are enforced after the
+        optimization."""
+        return (0.5, self.bounds[1])
+
 
 TRANSFORMATIONS = {
     'horizontal_translation': HorizontalTranslation,
