@@ -49,7 +49,6 @@ class RepresentativeMethods:
             representative meanoid / medianoid profile will be returned
             directly
         """
-        log_versions(logger)
         self._rep_method = self.rep_methods[rep_method]
         self._err_method = self.err_methods[err_method]
         self._profiles = profiles
@@ -300,9 +299,12 @@ class RepresentativeMethods:
 class RegionRepProfile:
     """Framework to handle rep profile for one resource region"""
 
-    def __init__(self, gen_fpath, rev_summary, gid_col='gen_gids',
-                 cf_dset='cf_profile', rep_method='meanoid', err_method='rmse',
-                 weight='gid_counts', n_profiles=1):
+    RES_GID_COL = 'res_gids'
+    GEN_GID_COL = 'gen_gids'
+
+    def __init__(self, gen_fpath, rev_summary, cf_dset='cf_profile',
+                 rep_method='meanoid', err_method='rmse', weight='gid_counts',
+                 n_profiles=1):
         """
         Parameters
         ----------
@@ -311,9 +313,8 @@ class RegionRepProfile:
         rev_summary : pd.DataFrame
             Aggregated rev supply curve summary file trimmed to just one
             region to get a rep profile for.
-        gid_col : str
-            Column label in rev_summary that contains the generation gids
-            (data index in gen_fpath).
+            Must include "res_gids", "gen_gids", and the "weight" column (if
+            weight is not None)
         cf_dset : str
             Dataset name to pull generation profiles from.
         rep_method : str
@@ -326,14 +327,13 @@ class RegionRepProfile:
         weight : str | None
             Column in rev_summary used to apply weighted mean to profiles.
             The supply curve table data in the weight column should have
-            weight values corresponding to the gid_col in the same row.
+            weight values corresponding to the res_gids in the same row.
         n_profiles : int
             Number of representative profiles to retrieve.
         """
 
         self._gen_fpath = gen_fpath
         self._rev_summary = rev_summary
-        self._gid_col = gid_col
         self._cf_dset = cf_dset
         self._profiles = None
         self._source_profiles = None
@@ -343,6 +343,50 @@ class RegionRepProfile:
         self._err_method = err_method
         self._weight = weight
         self._n_profiles = n_profiles
+        self._gen_gids = None
+        self._res_gids = None
+
+        self._init_profiles_weights()
+
+    def _init_profiles_weights(self):
+        """Initialize the base source profiles and weight arrays"""
+        gen_gids = self._get_region_attr(self._rev_summary, self.GEN_GID_COL)
+        res_gids = self._get_region_attr(self._rev_summary, self.RES_GID_COL)
+
+        self._weights = np.ones(len(res_gids))
+        if self._weight is not None:
+            self._weights = self._get_region_attr(self._rev_summary,
+                                                  self._weight)
+
+        df = pd.DataFrame({self.GEN_GID_COL: gen_gids,
+                           self.RES_GID_COL: res_gids,
+                           'weights': self._weights})
+        df = df.sort_values(self.RES_GID_COL)
+        self._gen_gids = df[self.GEN_GID_COL].values
+        self._res_gids = df[self.RES_GID_COL].values
+        if self._weight is not None:
+            self._weights = df['weights'].values
+        else:
+            self._weights = None
+
+        with Resource(self._gen_fpath) as res:
+            meta = res.meta
+
+            assert 'gid' in meta
+            source_res_gids = meta['gid'].values
+            msg = ('Resource gids from "gid" column in meta data from "{}" '
+                   'must be sorted! reV generation should always be run with '
+                   'sequential project points.'.format(self._gen_fpath))
+            assert np.all(source_res_gids[:-1] <= source_res_gids[1:]), msg
+
+            missing = set(self._res_gids) - set(source_res_gids)
+            msg = ('The following resource gids were found in the rev summary '
+                   'supply curve file but not in the source generation meta '
+                   'data: {}'.format(missing))
+            assert not any(missing), msg
+
+            iloc = np.where(np.isin(source_res_gids, self._res_gids))[0]
+            self._source_profiles = res[self._cf_dset, :, iloc]
 
     @property
     def source_profiles(self):
@@ -353,11 +397,6 @@ class RegionRepProfile:
         profiles : np.ndarray
             Timeseries array of cf profile data.
         """
-        if self._source_profiles is None:
-            gen_gids = self._get_region_attr(self._rev_summary, self._gid_col)
-            with Resource(self._gen_fpath) as res:
-                self._source_profiles = res[self._cf_dset, :, gen_gids]
-
         return self._source_profiles
 
     @property
@@ -371,15 +410,6 @@ class RegionRepProfile:
             curve table data in the weight column should have a list of weight
             values corresponding to the gen_gids list in the same row.
         """
-
-        if self._weights is None:
-            if self._weight is None:
-                self._weights = None
-            else:
-                self._weights = self._get_region_attr(self._rev_summary,
-                                                      self._weight)
-                self._weights = np.array(self._weights)
-
         return self._weights
 
     @staticmethod
@@ -391,6 +421,8 @@ class RegionRepProfile:
         rev_summary : pd.DataFrame
             Aggregated rev supply curve summary file trimmed to just one
             region to get a rep profile for.
+            Must include "res_gids", "gen_gids", and the "weight" column (if
+            weight is not None)
         attr_name : str
             Column label to extract flattened data from (gen_gids,
             gid_counts, etc...)
@@ -422,14 +454,12 @@ class RegionRepProfile:
         if self.weights is not None:
             if len(self.weights) != self.source_profiles.shape[1]:
                 e = ('Weights column "{}" resulted in {} weight scalars '
-                     'which doesnt match gid column "{}" which yields '
+                     'which doesnt match gid column which yields '
                      'profiles with shape {}.'
                      .format(self._weight, len(self.weights),
-                             self._gid_col, self.source_profiles.shape))
-                gen_gids = self._get_region_attr(self._rev_summary,
-                                                 self._gid_col)
-                logger.debug('Gids from column "{}" with len {}: {}'
-                             .format(self._gid_col, len(gen_gids), gen_gids))
+                             self.source_profiles.shape))
+                logger.debug('Gids from column "res_gids" with len {}: {}'
+                             .format(len(self._res_gids), self._res_gids))
                 logger.debug('Weights from column "{}" with len {}: {}'
                              .format(self._weight, len(self.weights),
                                      self.weights))
@@ -460,7 +490,7 @@ class RegionRepProfile:
     @property
     def rep_gen_gids(self):
         """Get the representative profile gen gids of this region."""
-        gids = self._get_region_attr(self._rev_summary, self._gid_col)
+        gids = self._gen_gids
         if self.i_reps[0] is None:
             rep_gids = None
         else:
@@ -471,11 +501,7 @@ class RegionRepProfile:
     @property
     def rep_res_gids(self):
         """Get the representative profile resource gids of this region."""
-        if self._gid_col == 'gen_gids':
-            gids = self._get_region_attr(self._rev_summary, 'res_gids')
-        else:
-            gids = None
-
+        gids = self._res_gids
         if self.i_reps[0] is None or gids is None:
             rep_gids = [None]
         else:
@@ -484,7 +510,7 @@ class RegionRepProfile:
         return rep_gids
 
     @classmethod
-    def get_region_rep_profile(cls, gen_fpath, rev_summary, gid_col='gen_gids',
+    def get_region_rep_profile(cls, gen_fpath, rev_summary,
                                cf_dset='cf_profile', rep_method='meanoid',
                                err_method='rmse', weight='gid_counts',
                                n_profiles=1):
@@ -497,9 +523,8 @@ class RegionRepProfile:
         rev_summary : pd.DataFrame
             Aggregated rev supply curve summary file trimmed to just one
             region to get a rep profile for.
-        gid_col : str
-            Column label in rev_summary that contains the generation gids
-            (data index in gen_fpath).
+            Must include "res_gids", "gen_gids", and the "weight" column (if
+            weight is not None)
         cf_dset : str
             Dataset name to pull generation profiles from.
         rep_method : str
@@ -512,7 +537,7 @@ class RegionRepProfile:
         weight : str | None
             Column in rev_summary used to apply weighted mean to profiles.
             The supply curve table data in the weight column should have
-            weight values corresponding to the gid_col in the same row.
+            weight values corresponding to the res_gids in the same row.
         n_profiles : int
             Number of representative profiles to retrieve.
 
@@ -527,7 +552,7 @@ class RegionRepProfile:
         res_gid_reps : list
             Resource gid(s) of the representative profile(s).
         """
-        r = cls(gen_fpath, rev_summary, gid_col=gid_col, cf_dset=cf_dset,
+        r = cls(gen_fpath, rev_summary, cf_dset=cf_dset,
                 rep_method=rep_method, err_method=err_method, weight=weight,
                 n_profiles=n_profiles)
 
@@ -538,8 +563,7 @@ class RepProfilesBase(ABC):
     """Abstract utility framework for representative profile run classes."""
 
     def __init__(self, gen_fpath, rev_summary, reg_cols=None,
-                 gid_col='gen_gids', cf_dset='cf_profile',
-                 rep_method='meanoid', err_method='rmse',
+                 cf_dset='cf_profile', rep_method='meanoid', err_method='rmse',
                  weight='gid_counts', n_profiles=1):
         """
         Parameters
@@ -548,13 +572,12 @@ class RepProfilesBase(ABC):
             Filepath to reV gen output file to extract "cf_profile" from.
         rev_summary : str | pd.DataFrame
             Aggregated rev supply curve summary file. Str filepath or full df.
+            Must include "res_gids", "gen_gids", and the "weight" column (if
+            weight is not None)
         reg_cols : str | list | None
             Label(s) for a categorical region column(s) to extract profiles
             for. e.g. "state" will extract a rep profile for each unique entry
             in the "state" column in rev_summary.
-        gid_col : str
-            Column label in rev_summary that contains the generation gids
-            (data index in gen_fpath).
         cf_dset : str
             Dataset name to pull generation profiles from.
         rep_method : str
@@ -567,7 +590,7 @@ class RepProfilesBase(ABC):
         weight : str | None
             Column in rev_summary used to apply weighted mean to profiles.
             The supply curve table data in the weight column should have
-            weight values corresponding to the gid_col in the same row.
+            weight values corresponding to the res_gids in the same row.
         n_profiles : int
             Number of representative profiles to save to fout.
         """
@@ -576,8 +599,6 @@ class RepProfilesBase(ABC):
                     .format(gen_fpath))
         logger.info('Running rep profiles with rev_summary: "{}"'
                     .format(rev_summary))
-        logger.info('Running rep profiles with gid column: "{}"'
-                    .format(gid_col))
         logger.info('Running rep profiles with region columns: "{}"'
                     .format(reg_cols))
         logger.info('Running rep profiles with representative method: "{}"'
@@ -588,7 +609,6 @@ class RepProfilesBase(ABC):
                     .format(weight))
 
         self._weight = weight
-        self._gid_col = gid_col
         self._n_profiles = n_profiles
         self._cf_dset = cf_dset
         self._gen_fpath = gen_fpath
@@ -599,7 +619,8 @@ class RepProfilesBase(ABC):
 
         self._check_req_cols(self._rev_summary, self._reg_cols)
         self._check_req_cols(self._rev_summary, self._weight)
-        self._check_req_cols(self._rev_summary, self._gid_col)
+        self._check_req_cols(self._rev_summary, RegionRepProfile.RES_GID_COL)
+        self._check_req_cols(self._rev_summary, RegionRepProfile.GEN_GID_COL)
 
         self._check_rev_gen(gen_fpath, cf_dset, self._rev_summary)
 
@@ -620,11 +641,15 @@ class RepProfilesBase(ABC):
         ----------
         rev_summary : str | pd.DataFrame
             Aggregated rev supply curve summary file. Str filepath or full df.
+            Must include "res_gids", "gen_gids", and the "weight" column (if
+            weight is not None)
 
         Returns
         -------
         rev_summary : pd.DataFrame
-            Aggregated rev supply curve summary file.
+            Aggregated rev supply curve summary file. Full df.
+            Must include "res_gids", "gen_gids", and the "weight" column (if
+            weight is not None)
         """
 
         if isinstance(rev_summary, str):
@@ -681,7 +706,9 @@ class RepProfilesBase(ABC):
         cf_dset : str
             Dataset name to pull generation profiles from.
         rev_summary : pd.DataFrame
-            Aggregated rev supply curve summary file.
+            Aggregated rev supply curve summary file. Full df.
+            Must include "res_gids", "gen_gids", and the "weight" column (if
+            weight is not None)
         """
         with Resource(gen_fpath) as res:
             dsets = res.datasets
@@ -861,9 +888,8 @@ class RepProfiles(RepProfilesBase):
     error metric vs. a mean or median profile.
     """
 
-    def __init__(self, gen_fpath, rev_summary, reg_cols, gid_col='gen_gids',
-                 cf_dset='cf_profile', rep_method='meanoid',
-                 err_method='rmse', weight='gid_counts',
+    def __init__(self, gen_fpath, rev_summary, reg_cols, cf_dset='cf_profile',
+                 rep_method='meanoid', err_method='rmse', weight='gid_counts',
                  n_profiles=1):
         """
         Parameters
@@ -872,13 +898,12 @@ class RepProfiles(RepProfilesBase):
             Filepath to reV gen output file to extract "cf_profile" from.
         rev_summary : str | pd.DataFrame
             Aggregated rev supply curve summary file. Str filepath or full df.
+            Must include "res_gids", "gen_gids", and the "weight" column (if
+            weight is not None)
         reg_cols : str | list | None
             Label(s) for a categorical region column(s) to extract profiles
             for. e.g. "state" will extract a rep profile for each unique entry
             in the "state" column in rev_summary.
-        gid_col : str
-            Column label in rev_summary that contains the generation gids
-            (data index in gen_fpath).
         cf_dset : str
             Dataset name to pull generation profiles from.
         rep_method : str
@@ -891,11 +916,12 @@ class RepProfiles(RepProfilesBase):
         weight : str | None
             Column in rev_summary used to apply weighted mean to profiles.
             The supply curve table data in the weight column should have
-            weight values corresponding to the gid_col in the same row.
+            weight values corresponding to the res_gids in the same row.
         n_profiles : int
             Number of representative profiles to save to fout.
         """
 
+        log_versions(logger)
         logger.info('Finding representative profiles that are most similar '
                     'to the weighted meanoid for each supply curve region.')
 
@@ -911,7 +937,7 @@ class RepProfiles(RepProfilesBase):
             reg_cols = list(reg_cols)
 
         super().__init__(gen_fpath, rev_summary, reg_cols=reg_cols,
-                         gid_col=gid_col, cf_dset=cf_dset,
+                         cf_dset=cf_dset,
                          rep_method=rep_method, err_method=err_method,
                          weight=weight, n_profiles=n_profiles)
 
@@ -976,9 +1002,9 @@ class RepProfiles(RepProfilesBase):
                              .format(i + 1, len(meta_static), region_dict))
                 out = RegionRepProfile.get_region_rep_profile(
                     self._gen_fpath, self._rev_summary[mask],
-                    gid_col=self._gid_col, cf_dset=self._cf_dset,
-                    rep_method=self._rep_method, err_method=self._err_method,
-                    weight=self._weight, n_profiles=self._n_profiles)
+                    cf_dset=self._cf_dset, rep_method=self._rep_method,
+                    err_method=self._err_method, weight=self._weight,
+                    n_profiles=self._n_profiles)
                 profiles, _, ggids, rgids = out
                 logger.info('Profile {} out of {} complete '
                             'for region: {}'
@@ -1038,7 +1064,6 @@ class RepProfiles(RepProfilesBase):
                         future = exe.submit(
                             RegionRepProfile.get_region_rep_profile,
                             self._gen_fpath, self._rev_summary[mask],
-                            gid_col=self._gid_col,
                             cf_dset=self._cf_dset,
                             rep_method=self._rep_method,
                             err_method=self._err_method,
@@ -1101,10 +1126,10 @@ class RepProfiles(RepProfilesBase):
         logger.info('Representative profiles complete!')
 
     @classmethod
-    def run(cls, gen_fpath, rev_summary, reg_cols, gid_col='gen_gids',
-            cf_dset='cf_profile', rep_method='meanoid', err_method='rmse',
-            weight='gid_counts', n_profiles=1, fout=None,
-            save_rev_summary=True, scaled_precision=False, max_workers=None):
+    def run(cls, gen_fpath, rev_summary, reg_cols, cf_dset='cf_profile',
+            rep_method='meanoid', err_method='rmse', weight='gid_counts',
+            n_profiles=1, fout=None, save_rev_summary=True,
+            scaled_precision=False, max_workers=None):
         """Run representative profiles by finding the closest single profile
         to the weighted meanoid for each SC region.
 
@@ -1114,13 +1139,12 @@ class RepProfiles(RepProfilesBase):
             Filepath to reV gen output file to extract "cf_profile" from.
         rev_summary : str | pd.DataFrame
             Aggregated rev supply curve summary file. Str filepath or full df.
+            Must include "res_gids", "gen_gids", and the "weight" column (if
+            weight is not None)
         reg_cols : str | list | None
             Label(s) for a categorical region column(s) to extract profiles
             for. e.g. "state" will extract a rep profile for each unique entry
             in the "state" column in rev_summary.
-        gid_col : str
-            Column label in rev_summary that contains the generation gids
-            (data index in gen_fpath).
         cf_dset : str
             Dataset name to pull generation profiles from.
         rep_method : str
@@ -1133,7 +1157,7 @@ class RepProfiles(RepProfilesBase):
         weight : str | None
             Column in rev_summary used to apply weighted mean to profiles.
             The supply curve table data in the weight column should have
-            weight values corresponding to the gid_col in the same row.
+            weight values corresponding to the res_gids in the same row.
         n_profiles : int
             Number of representative profiles to save to fout.
         fout : str, optional
@@ -1160,8 +1184,8 @@ class RepProfiles(RepProfilesBase):
             Datetime Index for represntative profiles
         """
 
-        rp = cls(gen_fpath, rev_summary, reg_cols, gid_col=gid_col,
-                 cf_dset=cf_dset, rep_method=rep_method, err_method=err_method,
+        rp = cls(gen_fpath, rev_summary, reg_cols, cf_dset=cf_dset,
+                 rep_method=rep_method, err_method=err_method,
                  n_profiles=n_profiles, weight=weight)
 
         rp._run(fout=fout, save_rev_summary=save_rev_summary,
